==> blancoNLpackGenerator-0.0.34-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/task/BlancoNLpackGeneratorParsePropertiesTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorParseProperties]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorParsePropertiesProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorParseProperties]̃NXB
 *
 * w肳ꂽfBNg̃vOCvpeBt@Cǂݍ݁A|󌋉ʃO(ResultDetailt@C)`ɏo܂BȂAǂݍ񂾒l |󌋉ʃO InputɃZbg܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorParsePropertiesBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratorparseproperties&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorParsePropertiesTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorParsePropertiesTask extends Task {
    /**
     * w肳ꂽfBNg̃vOCvpeBt@Cǂݍ݁A|󌋉ʃO(ResultDetailt@C)`ɏo܂BȂAǂݍ񂾒l |󌋉ʃO InputɃZbg܂B
     */
    protected BlancoNLpackGeneratorParsePropertiesProcessInput fInput = new BlancoNLpackGeneratorParsePropertiesProcessInput();

    /**
     * w肳ꂽfBNg̃vOCvpeBt@Cǂݍ݁A|󌋉ʃO(ResultDetailt@C)`ɏo܂BȂAǂݍ񂾒l |󌋉ʃO InputɃZbg܂B
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * w肳ꂽfBNg̃vOCvpeBt@Cǂݍ݁A|󌋉ʃO(ResultDetailt@C)`ɏo܂BȂAǂݍ񂾒l |󌋉ʃO InputɃZbg܂B
     */
    protected boolean fIsFieldTargetfileProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * ͂̃fBNgB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * ͂̃fBNgB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetfile(final String arg) {
        fInput.setTargetfile(arg);
        fIsFieldTargetfileProcessed = true;
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetfile() {
        return fInput.getTargetfile();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorParsePropertiesTask begin.");

        // ڔԍ[1]AAgr[g[sourcedir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldSourcedirProcessed == false) {
            throw new BuildException("K{Agr[g[sourcedir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[targetfile]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetfileProcessed == false) {
            throw new BuildException("K{Agr[g[targetfile]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- targetfile:[" + getTargetfile() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorParsePropertiesProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorParsePropertiesProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorParsePropertiesProcess proc = new BlancoNLpackGeneratorParsePropertiesProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorParsePropertiesBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoNLpackGenerator-0.1.12-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/task/BlancoNLpackGeneratorParsePropertiesTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorParseProperties]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorParsePropertiesProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorParseProperties]̃NXB
 *
 * w肳ꂽfBNg̃vOCvpeBt@Cǂݍ݁A|󌋉ʃO(ResultDetailt@C)`ɏo܂BȂAǂݍ񂾒l |󌋉ʃO InputɃZbg܂BÃ݂^[QbgP[݂̂ΏۂƂ܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorParsePropertiesBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratorparseproperties&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorParsePropertiesTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorParsePropertiesTask extends Task {
    /**
     * w肳ꂽfBNg̃vOCvpeBt@Cǂݍ݁A|󌋉ʃO(ResultDetailt@C)`ɏo܂BȂAǂݍ񂾒l |󌋉ʃO InputɃZbg܂BÃ݂^[QbgP[݂̂ΏۂƂ܂B
     */
    protected BlancoNLpackGeneratorParsePropertiesProcessInput fInput = new BlancoNLpackGeneratorParsePropertiesProcessInput();

    /**
     * tB[h [sourcedir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * tB[h [targetfile] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldTargetfileProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * ͂̃fBNgB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * ͂̃fBNgB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetfile(final String arg) {
        fInput.setTargetfile(arg);
        fIsFieldTargetfileProcessed = true;
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetfile() {
        return fInput.getTargetfile();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    @Override
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorParsePropertiesTask begin.");

        // ڔԍ[1]AAgr[g[sourcedir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldSourcedirProcessed == false) {
            throw new BuildException("K{Agr[g[sourcedir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[targetfile]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetfileProcessed == false) {
            throw new BuildException("K{Agr[g[targetfile]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- targetfile:[" + getTargetfile() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorParsePropertiesProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorParsePropertiesProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorParsePropertiesProcess proc = new BlancoNLpackGeneratorParsePropertiesProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorParsePropertiesBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
